@@ -12,6 +12,7 @@ LINE2 = 'settings.py:42: error: How are you?  [union-attr]\r\n'
 def run(cmd: list[str], exit_code: int = 0) -> str:
     stdout = StringIO()
     code = main(cmd, StringIO(), stdout)
-    assert code == exit_code
     stdout.seek(0)
-    return stdout.read()
+    result = stdout.read()
+    assert code == exit_code, result
+    return result
